<?php

namespace Drupal\voiceflow\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for the Voiceflow settings.
 */
class VoiceflowSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['voiceflow.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'voiceflow_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('voiceflow.settings');

    $form['enable_voiceflow'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Voiceflow Chatbot AI'),
      '#default_value' => $config->get('enable_voiceflow'),
    ];

    $form['project_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Project ID'),
      '#default_value' => $config->get('project_id'),
      '#required' => TRUE,
      '#description' => $this->t('Enter the Project ID for the Voiceflow integration.'),
    ];

    $form['exclude_paths'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Exclude paths'),
      '#default_value' => !empty($config->get('exclude_paths')) ? $config->get('exclude_paths') : '',
      '#description' => $this->t('Enter paths to exclude the Voiceflow Chatbot from appearing, one per line. You can use wildcards like "/admin/*".'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('voiceflow.settings')
      ->set('enable_voiceflow', $form_state->getValue('enable_voiceflow'))
      ->set('project_id', $form_state->getValue('project_id'))
      ->set('exclude_paths', trim($form_state->getValue('exclude_paths')))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
